import React from "react";
import { Fragment } from "react";
import { Pill } from "@fchh/fcos-suite-ui";
import Icon from "@components/Icon";
import type { IconPackageName } from "@config/index";
type IconSize = "sm" | "md" | "lg";
type BaseProps = {
  type:
    | "success"
    | "danger"
    | "warning"
    | "info"
    | "dark"
    | "default"
    | "purple"
    | "pink"
    | "white";
  title: string;
  rounded?: boolean;
  size: "sm" | "lg";
  className?: string;
};

type HrefOrNot =
  | {
      href: string;
      newTab?: boolean;
    }
  | {
      href?: never;
      newTab?: never;
    };

type IconOrWithoutIcon =
  | {
      icon?: never;
      iconPackage?: never;
      iconRight?: never;
      iconSize?: never;
    }
  | {
      icon: string;
      iconPackage?: IconPackageName;
      iconRight?: boolean;
      iconSize?: IconSize;
    };

type Props = BaseProps & HrefOrNot & IconOrWithoutIcon;

const PillWrapper: React.FC<Props> = ({iconPackage = "Carbon", icon, iconSize, ...restProps}) => {
  const ICON_SIZE_MAPPING: Record<IconSize, string> = {
    sm: "w-3 h-3",
    md: "w-4 h-4",
    lg: "w-5 h-5",
  };
  return (
    <Fragment>
      {icon ? (
        <Pill
          {...restProps}
          icon={
            <Icon
              pkg={iconPackage}
              name={icon}
              className={`${
                iconSize
                  ? ICON_SIZE_MAPPING[iconSize]
                  : ICON_SIZE_MAPPING["sm"]
              }`}
            />
          }
        />
      ) : (
        <Pill {...restProps} />
      )}
    </Fragment>
  );
};

export default PillWrapper;
